<TS version="2.1" language="et">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Paremkliki aadressi või sildi muutmiseks</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Loo uus aadress</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Uus</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopeeri</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">S&amp;ulge</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Kustuta valitud aadress nimekirjast</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Otsimiseks sisesta märgis või aadress</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Ekspordi kuvatava vahelehe sisu faili</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Ekspordi</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Kustuta</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Vali aadress millele mündid saata</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Vali aadress müntide vastuvõtmiseks</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">V&amp;ali</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Need on sinu Bitcoin aadressid maksete saatmiseks. Ennem müntide saatmist kontrolli alati summat ja makse saaja aadressi.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Need on sinu Bitcoin aadressid makse vastuvõtuks.Kasuta ‘Loo uus vastuvõttu aadress’ nuppu vastuvõtmise vahekaardis, et luua uus aadress. Allkirjastamine on võimalik ainult 'pärand' tüüpi aadressidega.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Kopeeri Aadress</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Kopeeri &amp;Silt</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Muuda</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Ekspordi Aadresside Nimekiri</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Komaga eraldatud fail</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Tõrge aadressi nimekirja salvestamisel %1. Palun proovi uuesti.</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Eksport ebaõnnestus.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Silt</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Aadress</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(silt puudub)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Salafraasi dialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Sisesta parool</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Uus parool</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Korda uut parooli</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Näita salafraasi</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Krüpteeri rahakott</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Antud operatsioon vajab rahakoti lahtilukustamiseks salafraasi.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Ava rahakoti lukk</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Muuda parooli</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Kinnita rahakoti krüpteerimine.</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Hoiatus:Kui sa krüpteerid oma rahakoti ja kaotad salafraasi, siis sa&lt;b&gt;KAOTAD OMA BITCOINID&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Kas oled kindel, et soovid rahakoti krüpteerida?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Rahakott krüpteeritud</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Sisesta rahakotile uus salafraas.&lt;br/&gt;Kasuta salafraasi millles on&lt;b&gt;kümme või rohkem juhuslikku sümbolit&lt;b&gt;,või&lt;b&gt;kaheksa või rohkem sõna&lt;b/&gt;.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Sisesta rahakoti vana salafraas ja uus salafraas.</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Pea meeles, et rahakoti krüpteerimine ei välista bitcoinide vargust, kui sinu arvuti on nakatunud pahavaraga.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Krüpteeritav rahakott</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Rahakott krüpteeritakse.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Rahakott krüpteeritud.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">TÄHTIS: Kõik varasemad rahakoti varundfailid tuleks üle kirjutada äsja loodud krüpteeritud rahakoti failiga. Turvakaalutlustel tühistatakse krüpteerimata rahakoti failid alates uue, krüpteeritud rahakoti, kasutusele võtust.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Rahakoti krüpteerimine ebaõnnestus</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Rahakoti krüpteerimine ebaõnnestus sisemise vea tõttu. Sinu rahakotti ei krüpteeritud.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Sisestatud paroolid ei kattu.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Rahakoti lahtilukustamine ebaõnnestus</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Rahakoti dekrüpteerimiseks sisestatud salafraas ei ole õige.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Rahakoti parooli vahetus õnnestus.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Hoiatus:Klaviatuuri suurtähelukk on peal.</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/Võrgumask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Blokeeritud kuni</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Süsteemisisene Viga</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Tõrge %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">tundmatu</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kogus</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An inbound connection from a peer. An inbound connection is a connection initiated by a peer.</extracomment>
        <translation type="unfinished">Sisenev</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An outbound connection to a peer. An outbound connection is a connection initiated by us.</extracomment>
        <translation type="unfinished">Väljuv</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 ja %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Ülevaade</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Kuva rahakoti üld-ülevaade</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Tehingud</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Sirvi tehingute ajalugu</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">V&amp;älju</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Välju rakendusest</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Teave %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Näita informatsiooni %1 kohta</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Teave &amp;Qt kohta</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Kuva Qt kohta käiv info</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Muuda %1 seadeid</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Loo uus rahakott</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Rahakott:</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Saada münte Bitcoini aadressile</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Varunda rahakott teise asukohta</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Rahakoti krüpteerimise salafraasi muutmine</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Saada</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Võta vastu</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Valikud</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Krüpteeri Rahakott...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Krüpteeri oma rahakoti privaatvõtmed</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Tagavara Rahakott...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Muuda Salasõna...</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Allkirjuta &amp;sõnum...</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Omandi tõestamiseks allkirjasta sõnumid oma Bitcoini aadressiga</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Kinnita sõnum...</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Kinnita sõnumid kindlustamaks et need allkirjastati määratud Bitcoini aadressiga</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Sulge Rahakott...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Loo Rahakott...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fail</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Seaded</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Abi</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Vahelehe tööriistariba</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Sünkroniseerin võrguga...</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Loo maksepäring (genereerib QR koodid ja bitcoini: URId)</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Käsurea valikud</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 ajast maas</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Viimane saabunud blokk loodi %1 tagasi.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Hilisemad transaktsioonid ei ole veel nähtavad.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Viga</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Hoiatus</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Informatsioon</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Ajakohane</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Ava Rahakott</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Ava Rahakott</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Sulge rahakott</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Taasta Rahakoti...</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Taasta rahakoti varukoopiafailist</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Sulge kõik rahakotid</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Migreeri rahakott</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Aken</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Pea Aken</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 klient</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Peida</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Tõrge %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Kuupäev: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Summa: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Tüüp: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">&amp;Märgis: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Aadress: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Saadetud tehing</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Sisenev tehing</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Rahakott on &lt;b&gt;krüpteeritud&lt;/b&gt; ning hetkel &lt;b&gt;avatud&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Rahakott on &lt;b&gt;krüpteeritud&lt;/b&gt; ning hetkel &lt;b&gt;suletud&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Kogus:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kogus</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Tasu:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Peale tehingutasu:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Vahetusraha:</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Puu režiim</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Loetelu režiim</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kogus</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Vastuvõetud märgisega</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Vastuvõetud aadressiga</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Kuupäev</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Kinnitused</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Kinnitatud</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopeeri tehingutasu</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopeeri baidid</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopeeri vahetusraha</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 lukustatud)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(silt puudub)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(vahetusraha)</translation>
    </message>
</context>
<context>
    <name>MigrateWalletActivity</name>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Migreeri rahakott</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Ava Rahakott</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Sulge rahakott</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Sulge kõik rahakotid</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Rahakott</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Muuda aadressi</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Märgis</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Aadress</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Uus saatev aadress</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Muuda vastuvõtvat aadressi</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Muuda saatvat aadressi</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Bitcoin address.</source>
        <translation type="unfinished">Sisestatud aadress "%1" ei ole korrektne Bitcoin aadress.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Rahakoti lahtilukustamine ebaõnnestus.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Uue võtme genereerimine ebaõnnestus.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>name</source>
        <translation type="unfinished">nimi</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">versioon</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Käsurea valikud</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>Do not shut down the computer until this window disappears.</source>
        <translation type="unfinished">Ära lülita arvutit välja ennem kui see aken on kadunud.</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Tere tulemast</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Viga</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Vorm</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Viimane ploki aeg</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Peida</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Kleebi aadress vahemälust</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Valikud</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;Peamine</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Taasta kõik klientprogrammi seadete vaikeväärtused.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Lähtesta valikud</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Võrk</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">R&amp;ahakott</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Ekspert</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">Proxi &amp;IP:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">Proxi port (nt 9050)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Aken</translation>
    </message>
    <message>
        <source>Show only a tray icon after minimizing the window.</source>
        <translation type="unfinished">Minimeeri systray alale.</translation>
    </message>
    <message>
        <source>&amp;Minimize to the tray instead of the taskbar</source>
        <translation type="unfinished">&amp;Minimeeri systray alale</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation type="unfinished">M&amp;inimeeri sulgemisel</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">&amp;Kuva</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">Kasutajaliidese &amp;keel:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation type="unfinished">Summade kuvamise &amp;Unit:</translation>
    </message>
    <message>
        <source>Choose the default subdivision unit to show in the interface and when sending coins.</source>
        <translation type="unfinished">Vali liideses ning müntide saatmisel kuvatav vaikimisi alajaotus.</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Katkesta</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">vaikeväärtus</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">puudub</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <extracomment>Window title text of pop-up window shown when the user has chosen to reset options.</extracomment>
        <translation type="unfinished">Kinnita valikute algseadistamine</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Viga</translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation type="unfinished">Sisestatud kehtetu proxy aadress.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Vorm</translation>
    </message>
    <message>
        <source>The displayed information may be out of date. Your wallet automatically synchronizes with the Bitcoin network after a connection is established, but this process has not completed yet.</source>
        <translation type="unfinished">Kuvatav info ei pruugi olla ajakohane. Ühenduse loomisel süngitakse sinu rahakott automaatselt Bitcoin võrgustikuga, kuid see toiming on hetkel lõpetamata.</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation type="unfinished">Ootel:</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation type="unfinished">Ebaküps:</translation>
    </message>
    <message>
        <source>Mined balance that has not yet matured</source>
        <translation type="unfinished">Mitte aegunud mine'itud jääk</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation type="unfinished">Kokku:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation type="unfinished">Hiljutised transaktsioonid</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>own address</source>
        <translation type="unfinished">oma aadress</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">või</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation type="unfinished">Maksepäringu tõrge</translation>
    </message>
    <message>
        <source>Cannot start bitcoin: click-to-pay handler</source>
        <translation type="unfinished">Bitcoin ei käivitu: vajuta-maksa toiming</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation type="unfinished">URI käsitsemine</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Direction</source>
        <extracomment>Title of Peers Table column which indicates the direction the peer connection was initiated from.</extracomment>
        <translation type="unfinished">Suund</translation>
    </message>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">Saadetud</translation>
    </message>
    <message>
        <source>Received</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have received from the peer.</extracomment>
        <translation type="unfinished">Vastu võetud</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Aadress</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Tüüp</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Võrk</translation>
    </message>
    <message>
        <source>Inbound</source>
        <extracomment>An Inbound Connection from a Peer.</extracomment>
        <translation type="unfinished">Sisenev</translation>
    </message>
    <message>
        <source>Outbound</source>
        <extracomment>An Outbound Connection to a Peer.</extracomment>
        <translation type="unfinished">Väljuv</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Copy Image</source>
        <translation type="unfinished">&amp;Kopeeri Pilt</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation type="unfinished">URI liiga pikk, proovi vähendada märke / sõnumi pikkust.</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation type="unfinished">Tõrge URI'st QR koodi loomisel</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation type="unfinished">Salvesta QR Kood</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation type="unfinished">Kliendi versioon</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Informatsioon</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Üldine</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation type="unfinished">Käivitamise hetk</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Võrk</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Nimi</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation type="unfinished">Ühenduste arv</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation type="unfinished">Blokiahel</translation>
    </message>
    <message>
        <source>Memory usage</source>
        <translation type="unfinished">Mälu kasutus</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation type="unfinished">&amp;Lähtesta</translation>
    </message>
    <message>
        <source>Received</source>
        <translation type="unfinished">Vastu võetud</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">Saadetud</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Versioon</translation>
    </message>
    <message>
        <source>Synced Headers</source>
        <translation type="unfinished">Sünkroniseeritud Päised</translation>
    </message>
    <message>
        <source>Synced Blocks</source>
        <translation type="unfinished">Sünkroniseeritud Plokid</translation>
    </message>
    <message>
        <source>Services</source>
        <translation type="unfinished">Teenused</translation>
    </message>
    <message>
        <source>Ping Time</source>
        <translation type="unfinished">Pingi Aeg</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Viimane ploki aeg</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="unfinished">&amp;Ava</translation>
    </message>
    <message>
        <source>&amp;Console</source>
        <translation type="unfinished">&amp;Konsool</translation>
    </message>
    <message>
        <source>&amp;Network Traffic</source>
        <translation type="unfinished">&amp;Võrgu Liiklus</translation>
    </message>
    <message>
        <source>Debug log file</source>
        <translation type="unfinished">Silumise logifail</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation type="unfinished">Puhasta konsool</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Jah</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Ei</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Saaja</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Saatja</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Teadmata</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Kogus:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Märgis</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">&amp;Sõnum:</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation type="unfinished">Puhasta kõik vormi väljad.</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished">Näita</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Eemalda</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Rahakoti lahtilukustamine ebaõnnestus.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kogus</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Märgis:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Sõnum:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Rahakott:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Kopeeri Aadress</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation type="unfinished">Makse Informatsioon</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Kuupäev</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Silt</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Sõnum</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(silt puudub)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation type="unfinished">(sõnum puudub)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Müntide saatmine</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation type="unfinished">automaatselt valitud</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation type="unfinished">Liiga suur summa</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Kogus:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Baiti:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kogus</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Tasu:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Peale tehingutasu:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Vahetusraha:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation type="unfinished">Tehingu tasu:</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation type="unfinished">kilobaidi kohta</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Peida</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation type="unfinished">Soovitatud:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Saatmine mitmele korraga</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation type="unfinished">Lisa &amp;Saaja</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation type="unfinished">Puhasta kõik vormi väljad.</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">Puhasta &amp;Kõik</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation type="unfinished">Jääk:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation type="unfinished">Saatmise kinnitamine</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">S&amp;aada</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopeeri kogus</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopeeri tehingutasu</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopeeri baidid</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopeeri vahetusraha</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">või</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation type="unfinished">Tehingutasu</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation type="unfinished">Müntide saatmise kinnitamine</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation type="unfinished">Saaja aadress ei ole korrektne. Palun kontrolli üle.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation type="unfinished">Makstav summa peab olema suurem kui 0.</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation type="unfinished">Summa ületab jäägi.</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation type="unfinished">Summa koos tehingu tasuga %1 ületab sinu jääki.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Warning: Invalid Bitcoin address</source>
        <translation type="unfinished">Hoiatus: Ebakorrektne Bitcoin aadress</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(silt puudub)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">S&amp;umma:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation type="unfinished">Maksa &amp;:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Märgis</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Vali eelnevalt kasutatud aadress</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Kleebi aadress vahemälust</translation>
    </message>
    <message>
        <source>S&amp;ubtract fee from amount</source>
        <translation type="unfinished">L&amp;ahuta tehingutasu summast</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Sõnum:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Signatures - Sign / Verify a Message</source>
        <translation type="unfinished">Signatuurid - Allkirjasta / Kinnita Sõnum</translation>
    </message>
    <message>
        <source>&amp;Sign Message</source>
        <translation type="unfinished">&amp;Allkirjastamise teade</translation>
    </message>
    <message>
        <source>The Bitcoin address to sign the message with</source>
        <translation type="unfinished">Bitcoin aadress millega sõnum allkirjastada</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Vali eelnevalt kasutatud aadress</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Kleebi aadress vahemälust</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation type="unfinished">Sisesta siia allkirjastamise sõnum</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished">Allkiri</translation>
    </message>
    <message>
        <source>Sign the message to prove you own this Bitcoin address</source>
        <translation type="unfinished">Allkirjasta sõnum Bitcoini aadressi sulle kuulumise tõestamiseks</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation type="unfinished">Allkirjasta &amp;Sõnum</translation>
    </message>
    <message>
        <source>Reset all sign message fields</source>
        <translation type="unfinished">Tühjenda kõik sõnumi allkirjastamise väljad</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation type="unfinished">Puhasta &amp;Kõik</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation type="unfinished">&amp;Kinnita Sõnum</translation>
    </message>
    <message>
        <source>The Bitcoin address the message was signed with</source>
        <translation type="unfinished">Bitcoin aadress millega sõnum on allkirjastatud</translation>
    </message>
    <message>
        <source>Verify the message to ensure it was signed with the specified Bitcoin address</source>
        <translation type="unfinished">Kinnita sõnum tõestamaks selle allkirjastatust määratud Bitcoini aadressiga.</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation type="unfinished">Kinnita &amp;Sõnum</translation>
    </message>
    <message>
        <source>Reset all verify message fields</source>
        <translation type="unfinished">Tühjenda kõik sõnumi kinnitamise väljad</translation>
    </message>
    <message>
        <source>Click "Sign Message" to generate signature</source>
        <translation type="unfinished">Allkirja loomiseks vajuta "Allkirjasta Sõnum"</translation>
    </message>
    <message>
        <source>The entered address is invalid.</source>
        <translation type="unfinished">Sisestatud aadress ei ole korrektne</translation>
    </message>
    <message>
        <source>Please check the address and try again.</source>
        <translation type="unfinished">Palun kontrolli aadressi ja proovi uuesti.</translation>
    </message>
    <message>
        <source>Wallet unlock was cancelled.</source>
        <translation type="unfinished">Rahakoti lahtilukustamine on katkestatud.</translation>
    </message>
    <message>
        <source>Private key for the entered address is not available.</source>
        <translation type="unfinished">Sisestatud aadressi privaatvõti pole saadaval.</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation type="unfinished">Sõnumi allkirjastamine ebaõnnestus.</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation type="unfinished">Sõnum allkirjastatud.</translation>
    </message>
    <message>
        <source>The signature could not be decoded.</source>
        <translation type="unfinished">Allkirja ei õnnestunud dekodeerida.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation type="unfinished">Palun kontrolli allkirja ja proovi uuesti.</translation>
    </message>
    <message>
        <source>The signature did not match the message digest.</source>
        <translation type="unfinished">Allkiri ei vastanud sõnumi krüptoräsile.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation type="unfinished">Sõnumi verifitseerimine ebaõnnestus.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation type="unfinished">Sõnum verifitseeritud.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>%1/unconfirmed</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in at least one block, but less than 6 blocks.</extracomment>
        <translation type="unfinished">%1/kinnitamata</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in 6 or more blocks.</extracomment>
        <translation type="unfinished">%1 kinnitust</translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished">Olek</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Kuupäev</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished">Allikas</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation type="unfinished">Genereeritud</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Saatja</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">tundmatu</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Saaja</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">oma aadress</translation>
    </message>
    <message>
        <source>label</source>
        <translation type="unfinished">märgis</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation type="unfinished">Krediit</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation type="unfinished">pole vastu võetud</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation type="unfinished">Deebet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation type="unfinished">Tehingutasu</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation type="unfinished">Neto summa</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Sõnum</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished">Kommentaar</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation type="unfinished">Transaktsiooni ID</translation>
    </message>
    <message>
        <source>Merchant</source>
        <translation type="unfinished">Kaupleja</translation>
    </message>
    <message>
        <source>Debug information</source>
        <translation type="unfinished">Debug'imise info</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation type="unfinished">Tehing</translation>
    </message>
    <message>
        <source>Inputs</source>
        <translation type="unfinished">Sisendid</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kogus</translation>
    </message>
    <message>
        <source>true</source>
        <translation type="unfinished">tõene</translation>
    </message>
    <message>
        <source>false</source>
        <translation type="unfinished">väär</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation type="unfinished">Paan kuvab tehingu detailid</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Kuupäev</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tüüp</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Silt</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation type="unfinished">Kinnitamata</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation type="unfinished">Kinnitatud (%1 kinnitust)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation type="unfinished">Loodud, kuid aktsepteerimata</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Saadud koos</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation type="unfinished">Kellelt saadud</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Saadetud</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Mine'itud</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(silt puudub)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation type="unfinished">Tehingu staatus. Kinnituste arvu kuvamiseks liigu hiire noolega selle peale.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation type="unfinished">Tehingu saamise kuupäev ning kellaaeg.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation type="unfinished">Tehingu tüüp.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation type="unfinished">Jäägile lisatud või eemaldatud summa.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation type="unfinished">Kõik</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished">Täna</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">Käesolev nädal</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Käimasolev kuu</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Eelmine kuu</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Käimasolev aasta</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Saadud koos</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Saadetud</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Mine'itud</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Muu</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation type="unfinished">Minimaalne summa</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Komaga eraldatud fail</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Kinnitatud</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Kuupäev</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tüüp</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Silt</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Aadress</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Eksport ebaõnnestus.</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">Vahemik:</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">saaja</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Loo uus rahakott</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Viga</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Müntide saatmine</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Ekspordi</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Ekspordi kuvatava vahelehe sisu faili</translation>
    </message>
    <message>
        <source>Backup Wallet</source>
        <translation type="unfinished">Varunda Rahakott</translation>
    </message>
    <message>
        <source>Backup Failed</source>
        <translation type="unfinished">Varundamine Ebaõnnestus</translation>
    </message>
    <message>
        <source>Backup Successful</source>
        <translation type="unfinished">Varundamine õnnestus</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>This is a pre-release test build - use at your own risk - do not use for mining or merchant applications</source>
        <translation type="unfinished">See on test-versioon - kasutamine omal riisikol - ära kasuta mining'uks ega kaupmeeste programmides</translation>
    </message>
    <message>
        <source>Corrupted block database detected</source>
        <translation type="unfinished">Tuvastati vigane bloki andmebaas</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Laetud</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation type="unfinished">Tõrge bloki andmebaasi käivitamisel</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation type="unfinished">Tõrge bloki baasi lugemisel</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation type="unfinished">Tõrge bloki andmebaasi avamisel</translation>
    </message>
    <message>
        <source>Failed to listen on any port. Use -listen=0 if you want this.</source>
        <translation type="unfinished">Pordi kuulamine nurjus. Soovikorral kasuta -listen=0.</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">Liiga suur summa</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation type="unfinished">Tehingu allkirjastamine ebaõnnestus</translation>
    </message>
    <message>
        <source>The transaction amount is too small to pay the fee</source>
        <translation type="unfinished">Tehingu summa on tasu maksmiseks liiga väikene</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation type="unfinished">Tehingu summa liiga väikene</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation type="unfinished">Tehing liiga suur</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation type="unfinished">Kirjeldatud tundmatu võrgustik -onlynet'is: '%s'</translation>
    </message>
    </context>
</TS>